@@ -67,7 +67,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
     let gen = quote! {
         mod checkout_server {
             pub use std::sync::Arc;
-            pub use checkout_core::cloud_pubsub;
             pub use checkout_core::dropshot::ApiDescription;
             pub use checkout_core::dropshot::ConfigDropshot;
             pub use checkout_core::dropshot::ConfigLogging;
@@ -79,6 +78,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub use checkout_core::internal_context::InternalContext;
 
             use std::env;
+            use checkout_core::cloud_pubsub;
             use checkout_core::dropshot;
             use checkout_core::dropshot::endpoint;
             use checkout_core::dropshot::RequestContext;
@@ -486,10 +486,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 let config = checkout_server::get_config();
 
-                let pubsub_client = checkout_server::Arc::new(checkout_server::cloud_pubsub::Client::new(config.google_application_credentials.clone()).await?);
-                let payment_processing_topic = checkout_server::Arc::new(pubsub_client.topic(config.payment_processing_topic.clone()));
-                let checkout_completion_topic: checkout_server::Arc::new(pubsub_client.topic(config.checkout_completion_topic.clone()));
-                let internal_context = checkout_server::InternalContext::new(payment_processing_topic, checkout_completion_topic).await.map_err(|_| checkout_server::new_server_error("failed to create internal context"))?;
+                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone(), config.checkout_completion_topic.clone()).await?;
 
                 let context_provider = checkout_server::Arc::new(self);
 
@@ -500,7 +497,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     },
                     api,
                     checkout_server::ServerContext {
-                        internal_context,
+                        internal_context: internal_context.clone(),
                         context_provider: context_provider.clone(),
                     },
                     &log,
